function [rfn,rfnModelID,Ns] = AtmosphericCorrectionCRPL( x, z, varargin )
% USAGE: [rfn,rfnModelID,Ns] = AtmosphericCorrectionCRPL( x, z )
%        [rfn,rfnModelID,Ns] = AtmosphericCorrectionCRPL( x, z, curve, rfnModel, NSurf, href)
%   curve   ='y' => make apply curved earth correction, else flat earth
%   rfnModel= 0  => Standard model, 1=> Exponential atmosphere
%   NSurf   = refractivity at surface (303 nominal)
%   href    = duct height (<100 m)
%   NOTE:  refractivity=(refractive index-1)*1.e6
%
% Translates model radial refractive index to rectangular
% coordinates (x,z) with origin on spherical earth at source location
% Default is standard CRPL model with 303 refractivity units at surface
% This model is close to 4/3 earth to 1000 km height increasing Ns 
% corresponds to denser atmosphere (more refraction)
% Surface duct is from standard model
%------------------CRPL model--------------------------
Re = 6378166;
if isempty(varargin)
    curve='y';
    rfnModel=0;
    NSurf=303;
    href=0;
    rfnModelID='CPRL';
elseif length(varargin)==4
    curve=varargin{1};
    rfnModel=varargin{2};
    if rfnModel==1
        rfnModelID='CRPL_Exp';
    end
    NSurf=varargin{3};
    href =varargin{4};
else
    error('AtmosphericCorrectionCRPL')
end

if( lower(curve) == 'y' )
   CF  = 2*Re*(sqrt(1-(x/Re)^2)-1);
   eta = z+Re*(sqrt(1+CF*z./(z+Re).^2)-1);
else
   eta = z;
end

if rfnModel==0 | rfnModel==1
    N=natmCRPL(eta,rfnModel,NSurf,href);
    rfn = N*1.e-6+1;
else
    error('Not Available')
end
return