function [Q] = Shkarofsky(Cs,gnu,qL,qs,q)
% Generate Shkarofsky Spectra Density Function
% [Canad. J. Phys.,46(19) 2133-2153] 
% Asymptotic form for small Q(q)~C*q^(-gnu) 
% INPUT PARAMETERS:
% Cs   = spectral strength parameter
% gnu = Spectral index parameter
% qL  = outter scal wavenumber
% qs  = inner scale wavenumber
% INPUT VECTOR:
% q   = wavenumber (radians/m)
%
% Charles L. Rino
% Vista Research, Inc.
% December 2, 1999
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if gnu < .5 | gnu > 1.5
   error('gnu parameter out of range')
end
r = 2*qL/qs;
e2=gnu+1/2;
dn2  = gamma(gnu-1)*Cs/(8*pi^1.5*gamma(gnu+1/2)*qL^(2*gnu-2));
f = sqrt(1+(q/qL).^2);
Q = dn2*(4*pi/qs/qL)^1.5*f.^(-e2).*besselk(e2,r*f)/besselk(gnu-1,r);
return