function D = ShkarofskyD(C,gnu,qL,qs,y)
% Generate Shkarofsky Structure Function
% [Canad. J. Phys.,46(19) 2133-2153] 

% INPUT PARAMETERS:
% C   = spectral strength parameter
% gnu = Spectral index parameter
% qL  = outter scal wavenumber
% qs  = inner scale wavenumber
% y   = separation (y=t-t')
%
% Charles L. Rino
% Vista Research, Inc.
% February 2004
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if gnu < 1 | gnu > 2
   error('gnu parameter out of range')
end
e=gnu-1;  r = 2*qL/qs; 
K=besselk(e,r);
C1=2*gamma(e)*C/(8*pi^1.5*gamma(gnu+1/2)); 

f = sqrt(1+(qs*y/2).^2);
D = C1*(1-f.^e.*besselk(e,r*f)/K)/qL^(2*gnu-2);
return