function N=natmCRPL(h_m,varargin)
%  USAGE natmCRPL(h_m) or natmCPRL(h_m,0,Ns,hs)  or natmCPRL(h_m,1,Ns)
%  Generate CPRL reference atmosphere refractivity
%  INPUT:
%        h_m   =   height above mean sea level in meters     (vector)
%        model =0  Standard CRPL  =1 exponential
%        Ns    =   Refractivity at surface height            (Default 303)           
%        delta =   Height of duct (m)                        (Default 0)
%            
%        model~=0  Simplified CRPL single exponential model 
%                  Ns must be specified
h_m=max(h_m,zeros(size(h_m)));
hs=0;
if isempty(varargin)
    model=0;
    Ns=303;
elseif length(varargin)==3
    model=varargin{1};
    Ns   =varargin{2};
    delta=varargin{3};
else 
    model=1;
    Ns   =varargin{2};
    delta=0;
end
h=h_m*1.e-3;
N=zeros(size(h));

if model==0
    DN=-7.32*exp(0.005577*Ns);
    N1=Ns+DN;
    c=1/(8-hs)*log(N1/105);
    i1=find(h<hs);
    if ~isempty(i1)
        N(i1)=Ns;
    end
    i2=find(h>=hs & h<=hs+1);
    if ~isempty(i2)
        N(i2)=Ns+(h(i2)-hs)*DN;
    end
    i3=find(h>hs+1 & h <=9);
    if ~isempty(i3)
        N(i3)=N1*exp(-c*(h(i3)-hs-1));
    end
    i4=find(h>9);
    if ~isempty(i4)
        N(i4)=105*exp(-0.1424*(h(i4)-9));
    end
elseif model==1
    N=Ns*exp(-0.139*h);
else
    error('model must be 0 or 1')
end
%Add Duct if delta>0  
%(R Paulus Model IEEE Antenna and Propagat,Vol38, No. 1990
if delta>0
    Re   = 6378166;
    cf=1.e6/Re;
    z0=1.5e-4;
    N=N-cf*(delta+z0)*log((h_m+z0)/z0).*exp(-h_m/500);
end