%  Process Ray Data generated by RunRayTrace_Earth
%  Spherical earth/Rays launched in plane intersecting z-axis
%  Rays terminated at spherical earth surface--Radius Re
%
%
rtd  = 180/pi;
dtr  = pi/180;
Re   = 6378166;   %Mean radius of earth
cvac=299792458;   %Speed of light in vacuum

%**********************************************************************************
%
load RayTraceEarth_Data
fprintf('Raytrace Data \n')
%fprintf('Lat= %6.2f Lon=%6.2f H=%6.2f m \n',origin(1)*rtd,origin(2)*rtd,H);
fprintf('Atmosphere: model %2i NO= %4.0f delta=%4.1f \n',model,N0,delta);
fprintf('%5i rays launched at %6.2f degs azimuth \n\n',length(Rays0),pmean*rtd);

Rays=Rays0;  clear Rays0

%R rotates from xyz to merdian plane (Assumes phi is constant=pmean)
R=[sin(pmean) cos(pmean); -cos(pmean) sin(pmean)];
xmin=1.e10; xmax=-xmin;
ymin=1.e10; ymax=-ymin;
zmin=1.e10; zmax=-zmin;

tdl     =NaN*ones(1,nrays);   %True delay (measured)
rng     =NaN*ones(1,nrays);   %True range
gza     =NaN*ones(1,nrays);   %True grazing angle in local tcs system
tcs     =NaN*ones(3,nrays);   %Surface position of rays
ct      =1+H/(Re);
figure
for nray=1:1:nrays
    %GO
    theta=Rays(nray).launch(2);
    theta_s=pi/2+theta;
    DD=(ct*cos(theta_s))^2-(ct^2-1);
    if DD>=0
        rg=Re*(ct*cos(theta_s)-sqrt(DD));
        theta_e=acos((ct^2+1-(rg/Re)^2)/(2*ct));
        xg=Re*sin(theta_e);
        zg=Re*(cos(theta_e)-1);
        xx=linspace(0,xg,100);
        zz=H+(zg-H)*xx/xg;
        hold on
        plot(xx/1000,zz,'c')
    end
    %Ray
    if Rays(nray).above_surface==0
        tdl(nray)=sum(Rays(nray).dn.*Rays(nray).ds)/cvac;                             %Path delay
        rng(nray)=sum(Rays(nray).ds);                                                 %Path length/True range
        sp=[R*[Rays(nray).tau(1,end); Rays(nray).tau(2,end)]; Rays(nray).tau(3,end)]; %Ray direction at surface
        xp2 =R*[Rays(nray).xyz(1,:); Rays(nray).xyz(2,:)];
        xp  =xp2(1,:);
        zp  =Rays(nray).xyz(3,:);
        %if phi(nray)==pmean
            %Keep track of overall ray extent
            xmax=max([xmax,Rays(nray).xyz(1,:)]); xmin=min([xmin,Rays(nray).xyz(1,:)]);
            ymax=max([ymax,Rays(nray).xyz(2,:)]); ymin=min([ymin,Rays(nray).xyz(2,:)]);
            zmax=max([zmax,Rays(nray).xyz(3,:)]); zmin=min([zmin,zp]);
            %Plot ray in meridian plane (xp,zp)
            hold on
            if DD<0
                col='m';
            else
                col='r';
            end
            plot(xp/1000,zp,col)
            tcs(:,nray)=Rays(nray).xyz(:,end);
            %Grazing angle to spherical earth intercept
            gza(nray)=-atan2(sp(3,end),sp(1,end))-asin(xp(end)/Re);
        %end
    end
end
%Calculate surface height  (1-D)
xpmax=R*[xmax; ymax];
tcs0=[R(1,2)*linspace(0,xpmax(1),500); R(1,1)*linspace(0,xpmax(1),500); zeros(1,500)];
height=-tcs2heightT(tcs0);
hold on
plot(linspace(0,xpmax(1),500)/1000,height,'b')
plot(0,H,'r<')
axis([0 xpmax(1)/1000 zmin zmax])
grid on
ylabel('Height--m')
xlabel('Distance--km')
title('Ray Paths in Standard Atmosphere-Spherical Earth')

thetag = acos((ct^2+1-(tdl*cbar/Re).^2)/(2*ct));    %Great circle angle to rnge
rg_hat = thetag;

figure
subplot(2,1,1)
plot(rng/1000,'r')
hold on
plot(tdl*cbar/1000,'b.-')
hold on
legend('True range','Delay range')
ylabel('km')
grid on
title('Estimated Range')
subplot(2,1,2)
plot(tdl*cbar-rng,'r')
ylabel('Error--m')
grid on
xlabel('Sample #')

figure
plot((tcs(1,:)-Re*sin(thetag)*cos(pmean)),(tcs(2,:)-Re*sin(thetag)*sin(pmean)),'bo')
grid on
xlabel('x-m')
ylabel('y-m')
title('Position Errors')


