%  Radar Mapping Demo
%
rtd  = 180/pi;
dtr  = pi/180;
Re   = 6378166;
cvac=299792458;

%Source Location
%Over Pacific Location of no particular consequence
Rlat=37.5;
Rlon=-145;
Rheight=1000;
origin =[Rlat; Rlon; 0]*dtr;


%Admospheric Model
model=1;
N0=303;       %Nominal surface refractivity for standard atmosphere
delta=0;
%**********************************************************************************

iDisplay=2;

%USER DEFINED PARAMETERS
DisplayRefractiveIndex=0;

H=Rheight;  %Height of source at origin of TCS system

%Use 4/3 earth model to estimate launch angle to horizon
ReK=4*Re/3;
phi_h=acos(ReK/(ReK+H));
nrays=70;
theta0=-phi_h+.000065;
dtheta=-.0005;
%Step downward (more negative)
theta=theta0+[0:nrays-1]*dtheta;      %Generate theta span
tspan=max(theta)-min(theta);
nrays=length(theta);
pmean=pi/4;
phi  =pi/4*ones(1,nrays);
zmax=H;
nlayers=500;
z=linspace(0,zmax,nlayers);
N=natmCRPL(z,model,N0,delta); %CPRL Standard atmosphere
cbar=cvac/median(1+N*1.e-6);
if DisplayRefractiveIndex
    cf=1.e6/Re;
    figure
    %subplot(2,1,1)
    plot(N,z/1000,'r')
    grid on
    xlabel('Refractivity')
    ylabel('H--km')
    title('CRPL Standard Atmosphere')
    if 0
        %Plot standard atmosphere in M-units
        figure
        subplot(2,1,2)
        plot(N+cf*z,z/1000,'r')
        grid on
        xlabel('M-units')
        ylabel('H-km')
    end
end
%-------------------------------------------------------------------------------------------
fprintf('\nRay Tracing \n')
Rays0=Launch_Rays_Earth(H,theta,phi,model,N0,delta);
fprintf('Done %s \n','Spherical Earth')
save RayTraceEarth_Data  Rays0 H nrays phi theta pmean cbar model N0 delta
